# Plugin ocr_translate_paddle

This is a plugin for the [ocr_translate](https://github.com/Crivella/ocr_translate).
Plugins to enable usage of [PaddleOCR](https://github.com/PaddlePaddle/PaddleOCR) in ocr_translate

## Usage

### ### For versions of the server `>=0.2`

- Install this by running `pip install ocr_translate-paddle`
- Add `ocr_translate_paddle` to your `INSTALLED_APPS` in `settings.py`
- Run the server with `AUTOCREATE_VALIDATED_MODELS` once

For versions of the server `>=0.6`

- Install through the server plugin manager

### For versions of the server `>=0.7`

- Install through the server plugin manager **OR** manually by running `pip install ocr_translate-paddle`
